Message Authentication Code (MAC)
This module provides implementations of message authentication codes that ensure data integrity and authenticity using cryptographic keys.
Modules
- hmac
- HMAC implementation according to FIPS 198-1.
- poly1305
- Module poly1305 implements Poly1305 one-time message authentication code as specified in https://cr.yp.to/mac/poly1305-20050329.pdf.